

import 'dart:developer';

import 'package:hub/flutter_flow/custom_functions.dart';
import 'package:hub/shared/components/molecules/menu/data/data_sources/menu_local_data_source.dart';
import 'package:hub/shared/components/molecules/menu/domain/respositories/menu_repository.dart';
import 'package:hub/shared/components/molecules/menu/index.dart';
import 'package:hub/shared/components/molecules/modules/index.dart';


class MenuRepositoryImpl implements MenuRepository {
  final MenuLocalDataSource menuDataSource = MenuLocalDataSourceImpl();

 
  @override
  Future<List<MenuItem?>> generateMenuEntries(List<MenuEntry> menuOptions, EnumMenuItem item) async {
    log('Generating menu entries for $item');
    List<MenuItem?> entries = [];
    try {
      for (var opt in menuOptions) {
        final bool isDefault = await menuDataSource.processDisplayDefault(item, opt, entries);
        if (isDefault) continue;
        final licenseValue = await LicenseRepositoryImpl().getLicense(opt.value);
        if (licenseValue != null) {
          final licenseMap = await stringToMap(licenseValue);
          final display = EnumDisplay.fromString(licenseMap['display']);
          final startDate = licenseMap['startDate'] ?? '';
          final expirationDate = licenseMap['expirationDate'] ?? '';
          final isStarted = await menuDataSource.processStartDate(startDate, opt);
          final isExpired = await menuDataSource.processExpirationDate(expirationDate, opt);
          if (isStarted && !isExpired) {
            await menuDataSource.processDisplay(item, display, opt, entries);
          }
        }
      }
    } catch (e, s) {
      log('Error generating menu entries: $e', stackTrace: s);
    }
    return entries;
  }



 
}