

import 'package:hub/shared/extensions/string_extensions.dart';
import 'package:hub/shared/helpers/storage/base_storage.dart';
import 'package:hub/shared/helpers/storage/storage_helper.dart';

import 'module.dart';


enum LicenseKeys {
  messages('FRE-HUB-MESSAGES'),
  liberations('FRE-HUB-LIBERATIONS'),
  reservations('FRE-HUB-RESERVATIONS'),
  access('FRE-HUB-ACCESS'),
  openedVisits('FRE-HUB-OPENED-VISITS'),
  vehicles('FRE-HUB-VEHICLES'),
  residents('FRE-HUB-RESIDENTS'),
  pets('FRE-HUB-PETS'),
  orders('FRE-HUB-ORDERS'),
  completeSchedule('FRE-HUB-COMPLETE-SCHEDULE'),
  providerSchedule('FRE-HUB-AGE-PROV-PRESTADOR'),
  deliverySchedule('FRE-HUB-AGE-PROV-DELIVERY'),
  property('FRE-HUB-PROPERTY'),
  fastPass('FRE-HUB-FASTPASS'),
  visitors('FRE-HUB-VISITORS'),
  qrCode('FRE-HUB-QRCODE'),
  people('FRE-HUB-PEOPLE'),
  petsHistory('FRE-HUB-PETS-HISTORY'),
  settings('FRE-HUB-SETTINGS'),
  logout('FRE-HUB-LOGOUT');


  final String value;
  const LicenseKeys(this.value);
}




class License {
  final List<Module> modules;

  const License(
    this.modules,
  );


  static Future<String> _processWithoutLicense(LicenseKeys key) async {
    switch(key) {
      case LicenseKeys.reservations: 
        return await _precessWpp();
      case LicenseKeys.orders:
        return await _precessWpp();
      case LicenseKeys.fastPass:
        return await _precessWpp();
      case LicenseKeys.providerSchedule:
        return await _processProvisional();
      case LicenseKeys.deliverySchedule:
        return await _processProvisional();
      case LicenseKeys.pets:
        return await _processPets();
      case LicenseKeys.petsHistory:
        return await _processPets();
      default:
        return ModuleStatus.active.key;
    }
  }

  static Future<String> _precessWpp() async {
    final bool whatsapp = await StorageHelper().get(KeychainStorageKey.whatsapp.value).then((v) => v.toBoolean());
    if (whatsapp) return ModuleStatus.active.key;
    else return ModuleStatus.inactive.key;
  }
  static Future<String> _processProvisional() async {
    final bool provisional = await StorageHelper().get(KeychainStorageKey.provisional.value).then((v) => v.toBoolean());
    if (provisional) return ModuleStatus.active.key;
    else return ModuleStatus.inactive.key;
  }

  static Future<String> _processPets() async {
    final bool pets = await StorageHelper().get(KeychainStorageKey.pets.value).then((v) => v.toBoolean());
    if (pets) return ModuleStatus.active.key;
    else return ModuleStatus.inactive.key;
  }

  static getKeyByModule(String s) {

  }
 

  static Future<License> getLicense(bool isNewVersion) async {
    return License([
    Module(
      key: LicenseKeys.messages.value,
      display: isNewVersion ? ModuleStatus.active.key : ModuleStatus.active.key,
      expirationDate: '',
      startDate: '',
      quantity: 0,
    ),
    Module(
      key: LicenseKeys.liberations.value,
      display: isNewVersion ? ModuleStatus.active.key : ModuleStatus.active.key,
      expirationDate: '',
      startDate: '',
      quantity: 0,
    ),
    Module(
      key: LicenseKeys.reservations.value,
      display: isNewVersion ? ModuleStatus.active.key : ModuleStatus.inactive.key,
      expirationDate: '',
      startDate: '',
      quantity: 0,
    ),
    Module(
      key: LicenseKeys.access.value,
      display: isNewVersion ? ModuleStatus.active.key : ModuleStatus.active.key,
      expirationDate: '',
      startDate: '',
      quantity: 0,
    ),
    Module(
      key: LicenseKeys.openedVisits.value,
      display: isNewVersion ? ModuleStatus.inactive.key : ModuleStatus.inactive.key,
      expirationDate: '',
      startDate: '',
      quantity: 0,
    ),
    Module(
      key: LicenseKeys.vehicles.value,
      display: isNewVersion ? ModuleStatus.inactive.key : ModuleStatus.inactive.key,
      expirationDate: '',
      startDate: '',
      quantity: 0,
    ),
    Module(
      key: LicenseKeys.residents.value,
      display: isNewVersion ? ModuleStatus.inactive.key : ModuleStatus.inactive.key,
      expirationDate: '',
      startDate: '',
      quantity: 0,
    ),
    Module(
      key: LicenseKeys.pets.value,
      display: isNewVersion ? ModuleStatus.active.key : await _processWithoutLicense(LicenseKeys.pets),
      expirationDate: '',
      startDate: '',
      quantity: 0,
    ),
    Module(
      key: LicenseKeys.orders.value,
      display: isNewVersion ? ModuleStatus.active.key : ModuleStatus.active.key,
      expirationDate: '',
      startDate: '',
      quantity: 0,
    ),
    Module(
      key: LicenseKeys.completeSchedule.value,
      display: isNewVersion ? ModuleStatus.active.key : ModuleStatus.active.key,
      expirationDate: '',
      startDate: '',
      quantity: 0,
    ),
    Module(
      key: LicenseKeys.providerSchedule.value,
      display: isNewVersion ? ModuleStatus.active.key : await _processWithoutLicense(LicenseKeys.providerSchedule),
      expirationDate: '',
      startDate: '',
      quantity: 0,
    ),
    Module(
      key: LicenseKeys.deliverySchedule.value,
      display: isNewVersion ? ModuleStatus.active.key : await _processWithoutLicense(LicenseKeys.deliverySchedule),
      expirationDate: '',
      startDate: '',
      quantity: 0,
    ),
    Module(
      key: LicenseKeys.fastPass.value,
      display: isNewVersion ? ModuleStatus.active.key : await _processWithoutLicense(LicenseKeys.fastPass),
      expirationDate: '',
      startDate: '',
      quantity: 0,
    ),
    Module(
      key: LicenseKeys.qrCode.value,
      display: isNewVersion ? ModuleStatus.active.key : ModuleStatus.active.key,
      expirationDate: '',
      startDate: '',
      quantity: 0,
    ),
    Module(
      key: LicenseKeys.visitors.value,
      display: isNewVersion ? ModuleStatus.active.key : ModuleStatus.active.key,
      expirationDate: '',
      startDate: '',
      quantity: 0,
    ),
    Module(
      key: LicenseKeys.property.value,
      display: isNewVersion ? ModuleStatus.inactive.key : ModuleStatus.inactive.key,
      expirationDate: '',
      startDate: '',
      quantity: 0,
    ),
    Module(
      key: LicenseKeys.people.value,
      display: isNewVersion ? ModuleStatus.inactive.key : ModuleStatus.active.key,
      expirationDate: '',
      startDate: '',
      quantity: 0,
    ),
    Module(
      key: LicenseKeys.petsHistory.value,
      display: isNewVersion ? ModuleStatus.active.key : await _processWithoutLicense(LicenseKeys.petsHistory),
      expirationDate: '',
      startDate: '',
      quantity: 0,
    ),
    Module(
      key: LicenseKeys.settings.value,
      display: isNewVersion ? ModuleStatus.active.key : ModuleStatus.active.key,
      expirationDate: '',
      startDate: '',
      quantity: 0,
    ),
    Module(
      key: LicenseKeys.logout.value,
      display: isNewVersion ? ModuleStatus.active.key : ModuleStatus.active.key,
      expirationDate: '',
      startDate: '',
      quantity: 0,
    ),
    
    ]);
  }
}

